@@ -17,6 +17,7 @@ class NotebookWrapper:
         inputVariable: str | List[str] | None,
         outputVariable: str | List[str] | None,
         inputTag: str = "input",
+        allowError: bool = False,
     ):
         self.notebook = Path(notebookFile)
 
@@ -29,6 +30,8 @@ class NotebookWrapper:
         self.outputVariable = outputVariable
 
         self.inputTag = inputTag
+        
+        self.allowError = allowError
 
         pass
 
@@ -71,7 +74,7 @@ class NotebookWrapper:
             else:
                 raise IOError(inputPath.__str__() + " took too much time to write.")
 
-            inputIndex = self._insertInputCell(inputPath)
+            inputIndex = self._insertInputCell(nb, inputPath)
 
         outputIndex = -1
         if self.outputVariable is not None:
@@ -85,10 +88,10 @@ class NotebookWrapper:
             )
             outputPath.parent.mkdir(parents=True, exist_ok=True)
 
-            outputIndex = self._insertOutputCell(outputPath)
+            outputIndex = self._insertOutputCell(nb, outputPath)
             pass
 
-        ep = ExecutePreprocessor(timeout=None)
+        ep = ExecutePreprocessor(timeout=None, allow_errors=self.allowError)
         resultNb, _ = ep.preprocess(nb, {"metadata": {"path": self.notebook.parent}})
 
         if _outputNotebook is not None:
@@ -103,10 +106,10 @@ class NotebookWrapper:
                     except Exception:
                         varStr = "This variable could not be represent in text."
                     mdText += f"- {variable}: {varStr}\n"
-                
+
                 mdCell = nbbase.new_markdown_cell(source=mdText)
                 resultNb.cells.insert(inputIndex, mdCell)
-                
+
             if outputIndex >= 0:
                 resultNb.cells.pop(outputIndex)
 
@@ -130,9 +133,7 @@ class NotebookWrapper:
         else:
             return None
 
-    def _insertInputCell(self, inputPath: Path):
-        nb = nbformat.read(self.notebook, as_version=nbformat.NO_CONVERT)
-
+    def _insertInputCell(self, nb, inputPath: Path):
         # identify input cell
         inputIndex = 0
         for i, cell in enumerate(nb.cells):
@@ -158,12 +159,7 @@ class NotebookWrapper:
 
         return inputIndex + 1
 
-    def _insertOutputCell(
-        self,
-        outputPath: Path,
-    ):
-        nb = nbformat.read(self.notebook, as_version=nbformat.NO_CONVERT)
-
+    def _insertOutputCell(self, nb, outputPath: Path):
         if isinstance(self.outputVariable, List):
             requestVars = "[" + ",".join(self.outputVariable) + "]"
         else:
